Effect implementors and their constructors.
Exploring this module is an easy way to discover what effects are available! The effects are roughly organized by the system parameter they mutate.
All of the native effect types have code examples, typically comparing a system that uses them to an equivalent impure system.
Modules
- algebra
Effectimplementations for generic algebraic data types.- asset
Effects that operate onAssetsstores and theAssetServer.- command
Effects that queueCommands.- entity_
command Effects that queue entity-specificCommands.- error
Effects for error handling.- iter
Effectimplementations for generic iterators.- local
Effects that modifyLocalparameters.- message
Effects that modifyMessageReaders andMessageWriters.- query
Effects that modifyQuerydata.- query_
entity Effects that modifyQuerydata for particular entities.- resource
Effects that modify resources.